summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/jabber/libiris/cutestuff/network/ndns.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/jabber/libiris/cutestuff/network/ndns.cpp')
-rw-r--r--kopete/protocols/jabber/libiris/cutestuff/network/ndns.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kopete/protocols/jabber/libiris/cutestuff/network/ndns.cpp b/kopete/protocols/jabber/libiris/cutestuff/network/ndns.cpp
index b94399ce..7db5defb 100644
--- a/kopete/protocols/jabber/libiris/cutestuff/network/ndns.cpp
+++ b/kopete/protocols/jabber/libiris/cutestuff/network/ndns.cpp
@@ -256,9 +256,9 @@ void NDnsManager::app_aboutToQuit()
//! This signal is emitted when the DNS resolution succeeds or fails.
//!
-//! Constructs an NDns object with tqparent \a tqparent.
-NDns::NDns(TQObject *tqparent)
-:TQObject(tqparent)
+//! Constructs an NDns object with parent \a parent.
+NDns::NDns(TQObject *parent)
+:TQObject(parent)
{
}